@@ -12,11 +12,9 @@ if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic.protos.query_service_messages_pb2 import (
         GeometryTimeSliceQueryRequest,
         Horizon,
-        LineBasedRectangle,
         LineTimeSliceQueryRequest,
-        PositionQuery,
     )
-    from cognite.seismic.protos.types_pb2 import CRS, GeoJson, Geometry, Wkt
+    from cognite.seismic.protos.types_pb2 import CRS, GeoJson, Geometry, Wkt, LineBasedRectangle, PositionQuery
 
 
 class TimeSliceAPI(API):
