@@ -320,6 +320,7 @@ class SeismicStore:
     coverage: Geometry
     text_header: Optional[TextHeader]
     binary_header: Optional[BinaryHeader]
+    storage_tier_name: List[str]
 
     def __init__(
         self,
@@ -335,6 +336,7 @@ class SeismicStore:
         coverage,
         text_header,
         binary_header,
+        storage_tier_name,
     ):
         self.id = id
         self.name = name
@@ -347,9 +349,10 @@ class SeismicStore:
         self.coverage = coverage
         self.text_header = text_header
         self.binary_header = binary_header
+        self.storage_tier_name = storage_tier_name
 
     def __repr__(self):
-        return f"SeismicStore<id: {self.id}, name: {self.name}, survey_id: {self.survey_id}, ingestion_source: {self.ingestion_source}, metadata: {self.metadata}>"
+        return f"SeismicStore<id: {self.id}, name: {self.name}, survey_id: {self.survey_id}, ingestion_source: {self.ingestion_source}, metadata: {self.metadata}, storage_tier: {self.storage_tier_name}>"
 
     @staticmethod
     def from_proto(proto) -> "SeismicStore":
@@ -368,6 +371,7 @@ class SeismicStore:
             coverage=proto.coverage,
             binary_header=BinaryHeader.from_proto(proto.binary_header),
             text_header=TextHeader.from_proto(proto.text_header),
+            storage_tier_name=proto.storage_tier_name,
         )
 
 
